@@ -1,10 +1,13 @@
 # -*- coding: utf-8 -*-
 
+"""Testing invalid cookiecutter template repositories."""
+
 import pytest
 
 from cookiecutter import main, exceptions
 
 
 def test_should_raise_error_if_repo_does_not_exist():
+    """Cookiecutter invocation with non-exist repository should raise error."""
     with pytest.raises(exceptions.RepositoryNotFound):
         main.cookiecutter('definitely-not-a-valid-repo-dir')
